Welcome to TSNet's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   limitations
   usage
   transient
   results
   examples
   validation
   contributing
   authors
   history
   API documentation <apidocs/tsnet>
   abbrev
   reference

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`